@@ -7,27 +7,27 @@ use strict;
 use Decision::Markov;
 ok(1, "Can use Decision::Markov");
 my $model = new Decision::Markov;
-ok(defined $model, "new() returned something");
-ok($model->isa('Decision::Markov'), " and it's the right class");
+ok(defined $model, "new()");
+ok($model->isa('Decision::Markov'), "class");
 my $well = $model->AddState("Well", 1);
 my $disabled = $model->AddState("Disabled", .5);
 my $dead = $model->AddState("Dead", 0);
 ok(defined($well) && defined($disabled) && defined($dead),
-	"AddState returned some things");
+	"AddState");
 ok($well->isa('Decision::Markov::State') &&
    $disabled->isa('Decision::Markov::State') &&
-   $dead->isa('Decision::Markov::State'), " and they're the right class");
+   $dead->isa('Decision::Markov::State'), "AddState class");
 my $error = $model->AddPath($well,$disabled,.2);
 $error = $model->AddPath($well,$dead,.05) || $error;
 $error = $model->AddPath($well,$well,.75) || $error;
 $error = $model->AddPath($disabled,$dead,.25) || $error; 
 $error = $model->AddPath($disabled,$disabled,.75) || $error;
 $error = $model->AddPath($dead,$dead,1) || $error;
-ok(!$error, "Transitions were added correctly");
+ok(!$error, "Transition adding");
 $error = $model->AddPath($well,$disabled,.7);
-ok($error, " and redundant transitions are correctly disallowed");
+ok($error, "Check for redundant transitions");
 $error = $model->Check;
-ok(!$error, "The model checks out");
+ok(!$error, "Model check");
 
 $model->Reset($well,1000);
 my $patients_left = $model->PatientsLeft;
@@ -37,7 +37,7 @@ while ($patients_left) {
   $cycle++;
 }
 my $avg_util_cohort = $model->CumUtility / 1000;
-ok((abs($avg_util_cohort - 5.096) < .001), "Cohort simulation worked");
+ok((abs($avg_util_cohort - 5.096) < .001), "Cohort simulation");
 
 my $numruns = 2;
 my $avg_util_mc = 0;
@@ -52,4 +52,4 @@ foreach (1..$numruns) {
   $avg_util_mc += $model->CumUtility;
 }
 $avg_util_mc /= $numruns;
-ok(defined $avg_util_mc, "Monte carlo simulation worked");
+ok(defined $avg_util_mc, "Monte carlo simulation");
